#+TITLE: Sacha Chua's Emacs configuration
#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post
#+ELEVENTY_BASE_URL: https://sachachua.com
* Linking to Org Babel source in a comment, and making that always use file links :org:
:PROPERTIES:
:CUSTOM_ID: org-babel-comments
:EXPORT_DATE: 2024-12-29T08:41:17-0500
:EXPORT_ELEVENTY_PERMALINK: /blog/2024/12/linking-to-org-babel-source-in-a-comment-and-making-that-always-use-file-links/
:EXPORT_ELEVENTY_FILE_NAME: blog/2024/12/linking-to-org-babel-source-in-a-comment-and-making-that-always-use-file-links/
:END:

I've been experimenting with these default header
args for Org Babel source blocks.

#+NAME: org-babel-default-header-args
#+begin_src emacs-lisp
(setq org-babel-default-header-args
      '((:session . "none")
        (:results . "drawer replace")
				(:comments . "link")  ;; add a link to the original source
        (:exports . "both")
        (:cache . "no")
        (:eval . "never-export") ;; explicitly evaluate blocks instead of evaluating them during export
        (:hlines . "no")
        (:tangle . "no"))) ;; I have to explicitly set up blocks for tangling
#+end_src

In particular, ~:comments link~ adds a comment
before each source block with a link to the file
it came from. This allows me to quickly jump to
the actual definition. It also lets me use
~org-babel-detangle~ to copy changes back to my
Org file.

I also have a custom link type to make it easier
to link to sections of my configuration file
([[dotemacs:links-to-my-config][Links to my config]]). Org Mode prompts for the
link type to use when more than one function
returns a link for storing, so that was
interrupting my tangling with lots of interactive
prompts. The following piece of advice ignores all
the custom link types when tangling the link
reference. That way, the link reference always
uses the ~file:~ link instead of offering my
custom link types.

#+begin_src emacs-lisp :lexical t :exports code
(advice-add #'org-babel-tangle--unbracketed-link
						:around (lambda (old-fun &rest args)
											(let (org-link-parameters)
												(apply old-fun args))))
#+end_src


